# Follow complete workflows

:::{figure} images/select-options-2.png
Model options to select
:::

  > {ref}`A. "Select an existing model" workflow<Select an existing model>`
  >
  > {ref}`B. "Start a new model" workflow<Start a new model>`

:::{warning}
If no model option is selected, the `Curation`, `Training`, and `Prediction` tabs below this section will stay inactive and unavailable for interaction.
:::

:::{toctree}
:hidden:
1_Start-new-model
2_Select-existing-model
:::
